@@ -8,6 +8,7 @@ from sqlalchemy import exists
 from sqlalchemy import select
 from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy.sql import selectable
+from sqlalchemy.sql.elements import BinaryExpression
 from unimatrix.ext.model.exc import ValidationError
 
 
@@ -59,6 +60,8 @@ class NamedQuery(metaclass=NamedQueryMeta):
         selectable.Selectable,
     )
 
+    supported_predicates = tuple([BinaryExpression])
+
     def __init__(self, *args, **kwargs):
         schema = self.schema_class()
         try:
@@ -75,8 +78,10 @@ class NamedQuery(metaclass=NamedQueryMeta):
                 for p in self.predicate:
                     if callable(p):
                         query = query.where(p(self, query))
+                    elif isinstance(p, self.supported_predicates):
+                        query = query.where(p)
                     else:
-                        raise NotImplementedError
+                        raise NotImplementedError(p)
             elif isinstance(self.predicate, eq):
                 query = query.where(self.predicate(self, query))
             else:
